@@ -32,7 +32,7 @@ def exists(name):
 def to_json_dict():
 	"""
 	Returns a dictionary representation of the definition index
-	(name => Definition).
+	(name => Definition). Currently BROKEN.
 
 	:rtype: dict
 	:return: A serializable dict representation of the definition index.
@@ -42,8 +42,8 @@ def to_json_dict():
 
 def from_json_dict(root):
 	"""
-	Instantiates definitions from a dictionary. See the format spec for
-	more details.
+	Instantiates definitions from a dictionary. See the :doc:`Serialization
+	Guide </serialization_guide>`.
 
 	:return: None
 	"""
@@ -246,7 +246,7 @@ def register_definition(
 			meta=Utils.Empty
 		):
 	"""
-	Register a definition.
+	Register a definition. See the :doc:`Definition Guide </definition_guide>`.
 
 	:param str name: Indexed name used to access and refer to this definition.
 	:param list aliases: List of strings which will be indexed as aliases.
@@ -479,6 +479,25 @@ def recurse_definition(
 			)
 
 
+def list_referenced_definitions(
+			definition_or_name
+		):
+	"""
+	Return a set of definitions referenced by the given definition i.e. the
+	fields of an object or the data type(s) for an array. All referenced
+	definitions are returned (recursive). NOTE: All definitions referenced
+	across all versions will be returned.
+
+	:param definition_or_name: Either Definition object or string name of definition.
+	:param str version: Specific version or latest by default.
+	:return: Returns set of definitions referenced by the given definition (children only).
+	"""
+	result = Definitions.Index.list_referenced_definitions(
+			definition_or_name
+		)
+	return result
+
+
 def set_default_version(default_version):
 	"""
 	The default version is "base". Calling set_default_version will cause any calls
