@@ -1,8 +1,10 @@
 import cro_validate.api.configuration_api as ConfigApi
 
 def get_example_generator(definition, **kw):
-	generator = ConfigApi.get_example_generator_factory().create(definition, **kw)
-	return generator
+	"""
+	Get an instance of an example generator implementation via the configured factory.
 
-def get_default_examples(definition, **kw):
-	return ConfigApi.get_default_examples_provider().get_examples(definition, **kw)
\ No newline at end of file
+	:returns: Example generator implementation.
+	"""
+	generator = ConfigApi.get_example_generator_factory().create(definition, **kw)
+	return generator
\ No newline at end of file
