@@ -273,9 +273,9 @@ class Definition:
 		# Examples
 		##########
 		if not self.examples:
-			self.examples = Config.default_examples_provider.get_examples(self)
+			self.examples = [] # Removed req for examples, next statements pending srs confirm: Config.default_examples_provider.get_examples(self)
 		if not self.is_object() and not self.is_array():
-			if not self.examples:
+			if self.examples is None:
 				raise Config.exception_factory.create_input_error(self.name, 'Missing examples')
 		# Meta
 		######
@@ -915,7 +915,7 @@ class Index:
 
 	def get(definition_or_name, version=Utils.Empty):
 		definition_name = Index._resolve_definition_name(definition_or_name)
-		if Utils.Empty.isempty(version) is not True:
+		if Utils.Empty.isempty(version, none_is_empty=True) is not True:
 			if version not in Index._versions:
 				raise Config.exception_factory.create_internal_error(
 						definition_name,
@@ -924,7 +924,7 @@ class Index:
 		versions = Index._ensure_loaded(definition_name)
 		# Latest
 		########
-		if Utils.Empty.isempty(version) is True:
+		if Utils.Empty.isempty(version, none_is_empty=True) is True:
 			latest_version = Index.get_latest_version()
 			final_definition = Index.get_definition_final_version(definition_name)
 			if Index.compare_versions(latest_version, final_definition.get_version()) == 1:
@@ -1109,8 +1109,12 @@ class Index:
 			elif mutation.action == VersionMutationType.RenameField:
 				old_field_name = mutation.config['field_name']
 				old_field = mutated_model[old_field_name]
+				new_field_name = mutation.config['new_field_name']
 				new_field = old_field.copy()
-				new_field.mutate(input_name=mutation.config['field_name'])
+				if old_field.input_name == old_field_name:
+					new_field.mutate(input_name=new_field_name)
+				if old_field.output_name == old_field_name:
+					new_field.mutate(input_name=new_field_name)
 				del mutated_model[old_field_name]
 				mutated_model[mutation.config['new_field_name']] = new_field
 		return mutated_model
@@ -1274,8 +1278,9 @@ class Index:
 				**rules_kw
 			):
 		data_format = definition.get_data_format()
-		if not isinstance(data_format, collections.Hashable):
-			# currently not supported; FUTURES
+		if not isinstance(data_format, collections.abc.Hashable):
+			# data_format is user-defined and must be hashable.
+			# TODO: Add common logging iface like exceptions.
 			return
 		if data_format not in Index._data_format_rules:
 			return
@@ -1378,6 +1383,31 @@ class Index:
 		result.sort()
 		return result
 
+	def list_referenced_definitions(
+				definition_or_name,
+				referenced=set()
+			):
+		children = set(referenced)
+		definition = Index.get_definition_final_version(definition_or_name)
+		children.add(definition.get_name())
+		versions = Index.list_definition_versions(definition, include_identical=True)
+		for version in versions:
+			if Index.definition_has_version(definition, version) is False:
+				continue
+			definition_version = Index.get(definition, version)
+			if definition_version.is_object():
+				fields = definition_version.list_fields()
+				for field_name in fields:
+					field = fields[field_name]
+					if field.definition_name in children:
+						continue
+					children.update(Index.list_referenced_definitions(field.definition_name, referenced=children))
+			elif definition_version.is_array():
+				item_definition = Index.get(definition_version.data_format, version)
+				children.add(item_definition.get_name())
+				children.update(Index.list_referenced_definitions(item_definition, referenced=children))
+		return children
+
 	def clear():
 		Index._idx = {}
 		Index._data_type_rules = {}
