@@ -12,11 +12,14 @@ class ClassName:
 
 
 class Empty:
-	def isempty(v):
+	def isempty(v, none_is_empty=False):
 		if isinstance(v, Empty):
 			return True
 		if v is Empty:
 			return True
+		if none_is_empty is True:
+			if v is None:
+				return True
 		return False
 
 
